Managing Data
=============

.. toctree::
  :maxdepth: 2
  :hidden:


  ../api/tom_dataproducts/views
  plotting_data
  customizing_data_processing
  tom_direct_sharing
  stream_pub_sub
  continuous_sharing
  single_target_data_service


:doc:`Creating Plots from TOM Data <plotting_data>` - Learn how to create plots using plot.ly and your TOM
data to display anywhere in your TOM.

:doc:`Adding Custom Data Processing <customizing_data_processing>` - Learn how you can process data into your
TOM from uploaded data products.

:doc:`TOM-TOM Direct Sharing <tom_direct_sharing>` - Learn how you can send and receive data between your TOM and another TOM-Toolkit TOM via an API.

:doc:`Publish and Subscribe to a Kafka Stream <stream_pub_sub>` - Learn how to publish and subscribe to a Kafka stream topic.

:doc:`Setting up Continuous Sharing of a target's data to a TOM or Kafka stream <continuous_sharing>` - Learn how to set up continuous sharing of a Target's data products.

:doc:`Integrating Single-Target Data Service Queries <single_target_data_service>` - Learn how to integrate the existing Atlas, panSTARRS, and ZTF
single-target data services into your TOM, and learn how to add new services.
